aboutsummaryrefslogtreecommitdiff
path: root/lib/hostip.c
diff options
context:
space:
mode:
authorDan Fandrich <dan@coneharvesters.com>2007-09-28 18:47:59 +0000
committerDan Fandrich <dan@coneharvesters.com>2007-09-28 18:47:59 +0000
commit83883668494930839b2a959314c72d9aa511d340 (patch)
tree3aeff0e2b1bf32899c91dda67f856c8d35fbdc22 /lib/hostip.c
parentef3b425b1136c11816489f274ca040f7d9146888 (diff)
Renamed a variable to avoid shadowing a global declarations.
Diffstat (limited to 'lib/hostip.c')
-rw-r--r--lib/hostip.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/hostip.c b/lib/hostip.c
index 02f4da06f..7f143fb98 100644
--- a/lib/hostip.c
+++ b/lib/hostip.c
@@ -398,7 +398,6 @@ int Curl_resolv(struct connectdata *conn,
char *entry_id = NULL;
struct Curl_dns_entry *dns = NULL;
size_t entry_len;
- int wait;
struct SessionHandle *data = conn->data;
CURLcode result;
int rc;
@@ -447,19 +446,20 @@ int Curl_resolv(struct connectdata *conn,
/* The entry was not in the cache. Resolve it to IP address */
Curl_addrinfo *addr;
+ int respwait;
/* Check what IP specifics the app has requested and if we can provide it.
* If not, bail out. */
if(!Curl_ipvalid(data))
return CURLRESOLV_ERROR;
- /* If Curl_getaddrinfo() returns NULL, 'wait' might be set to a non-zero
- value indicating that we need to wait for the response to the resolve
- call */
- addr = Curl_getaddrinfo(conn, hostname, port, &wait);
+ /* If Curl_getaddrinfo() returns NULL, 'respwait' might be set to a
+ non-zero value indicating that we need to wait for the response to the
+ resolve call */
+ addr = Curl_getaddrinfo(conn, hostname, port, &respwait);
if (!addr) {
- if(wait) {
+ if(respwait) {
/* the response to our resolve call will come asynchronously at
a later time, good or bad */
/* First, check that we haven't received the info by now */